@@ -11,10 +11,15 @@
 #' # SEQUENCE: QWGRRCCGWGPGRRYCVRWC 
 #' # Theoretical pI/Mw: 9.88 / 2485.91 
 #' 
-#' mw("QWGRRCCGWGPGRRYCVRWC")
+#' mw(seq = "QWGRRCCGWGPGRRYCVRWC",monoisotopic = FALSE)
 #' # [1] 2485.911
+#' 
+#' mw(seq = "QWGRRCCGWGPGRRYCVRWC",monoisotopic = TRUE)
+#' # [1] 2484.12
 mw <- function(seq, monoisotopic = FALSE) {
-  seq <- gsub("[[:space:]]", "", seq)
+  # Split sequence by amino acids
+  seq <- aaCheck(seq)
+  
   # Create the weight scale
   if (monoisotopic == TRUE) {
     weight <-
@@ -74,7 +79,6 @@ mw <- function(seq, monoisotopic = FALSE) {
   
   # Sum the weight of each amino acid and add H2O weight
   unlist(lapply(seq, function(seq) {
-    sum(weight[c(strsplit(toupper(seq), split = "")[[1]], "H2O")], na.rm =
-          TRUE)
+    sum(weight[c(seq, "H2O")], na.rm = TRUE)
   }))
 }
